pub struct SumcheckData<F, EF> {
pub polynomial_evaluations: Vec<[EF; 2]>,
pub pow_witnesses: Vec<F>,
}Expand description
Sumcheck polynomial data
Stores the polynomial evaluations for sumcheck rounds in a compact format.
Each round stores [h(0), h(inf)] where h(1) is derived as claimed_sum - h(0).
Fields
polynomial_evaluations: Vec<[EF; 2]>Polynomial evaluations for each sumcheck round.
Each entry is [h(0), h(inf)]:
h(0)is the constant term.h(inf)is the leading coefficient (evaluation at infinity).
h(1) is derived as claimed_sum - h(0) by the verifier.
Length: folding_factor
pow_witnesses: Vec<F>PoW witnesses for each sumcheck round Length: folding_factor
Implementations
Sourceimpl<F, EF> SumcheckData<F, EF>
impl<F, EF> SumcheckData<F, EF>
Sourcepub fn polynomial_evaluations(&self) -> &[[EF; 2]]
pub fn polynomial_evaluations(&self) -> &[[EF; 2]]
Returns the polynomial evaluations [h(0), h(inf)] for each round.
Sourcepub const fn num_rounds(&self) -> usize
pub const fn num_rounds(&self) -> usize
Returns the number of rounds stored in this proof data.
Sourcepub fn observe_and_sample<Challenger, BF>(
&mut self,
challenger: &mut Challenger,
c0: EF,
c_inf: EF,
pow_bits: usize,
) -> EFwhere
BF: Field,
EF: ExtensionField<BF>,
F: Clone,
Challenger: FieldChallenger<BF> + GrindingChallenger<Witness = F>,
pub fn observe_and_sample<Challenger, BF>(
&mut self,
challenger: &mut Challenger,
c0: EF,
c_inf: EF,
pow_bits: usize,
) -> EFwhere
BF: Field,
EF: ExtensionField<BF>,
F: Clone,
Challenger: FieldChallenger<BF> + GrindingChallenger<Witness = F>,
Commits polynomial coefficients to the transcript and returns a challenge.
This helper function handles the Fiat-Shamir interaction for a sumcheck round.
Arguments
challenger- Fiat-Shamir transcript.c0- Constant coefficienth(0).c_inf- Leading coefficienth(inf).pow_bits- PoW difficulty (0 to skip grinding).
Returns
The sampled challenge r.
Sourcepub fn verify_rounds<Challenger>(
&self,
challenger: &mut Challenger,
claimed_sum: &mut EF,
pow_bits: usize,
) -> Result<Point<EF>, SumcheckError>where
F: TwoAdicField,
EF: ExtensionField<F> + TwoAdicField,
Challenger: FieldChallenger<F> + GrindingChallenger<Witness = F>,
pub fn verify_rounds<Challenger>(
&self,
challenger: &mut Challenger,
claimed_sum: &mut EF,
pow_bits: usize,
) -> Result<Point<EF>, SumcheckError>where
F: TwoAdicField,
EF: ExtensionField<F> + TwoAdicField,
Challenger: FieldChallenger<F> + GrindingChallenger<Witness = F>,
Verifies standard sumcheck rounds and extracts folding randomness from the transcript.
Returns
A Point of folding randomness values.