pub struct TableSpec { /* private fields */ }Expand description
Description of a table used to build randomized stacked-sumcheck witnesses.
Implementations
Sourceimpl TableSpec
impl TableSpec
Sourcepub fn new(shape: TableShape, point_schedule: PointSchedule) -> Self
pub fn new(shape: TableShape, point_schedule: PointSchedule) -> Self
Builds a table spec from a shape and point-local opening schedule.
Panics
- Every scheduled polynomial index must be less than the table width.
Sourcepub const fn shape(&self) -> &TableShape
pub const fn shape(&self) -> &TableShape
Returns the logical table shape.
Sourcepub const fn point_schedule(&self) -> &PointSchedule
pub const fn point_schedule(&self) -> &PointSchedule
Returns the point-local opening schedule.
Sourcepub const fn pad_to_min_num_variables(&mut self, min_num_variables: usize)
pub const fn pad_to_min_num_variables(&mut self, min_num_variables: usize)
Pads this table shape to at least min_num_variables.